==> camel_ai-0.2.15a0-py3-none-any.whl: camel/types/__init__.py <==
# ========= Copyright 2023-2024 @ CAMEL-AI.org. All Rights Reserved. =========
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ========= Copyright 2023-2024 @ CAMEL-AI.org. All Rights Reserved. =========
from .enums import (
    AudioModelType,
    EmbeddingModelType,
    HuggingFaceRepoType,
    ModelPlatformType,
    ModelType,
    OpenAIBackendRole,
    OpenAIImageType,
    OpenAIVisionDetailType,
    OpenAPIName,
    RoleType,
    StorageType,
    TaskType,
    TerminationMode,
    VectorDistance,
    VoiceType,
)
from .openai_types import (
    NOT_GIVEN,
    ChatCompletion,
    ChatCompletionAssistantMessageParam,
    ChatCompletionChunk,
    ChatCompletionFunctionMessageParam,
    ChatCompletionMessage,
    ChatCompletionMessageParam,
    ChatCompletionSystemMessageParam,
    ChatCompletionUserMessageParam,
    Choice,
    CompletionUsage,
    NotGiven,
    ParsedChatCompletion,
)
from .unified_model_type import UnifiedModelType

__all__ = [
    'RoleType',
    'ModelType',
    'TaskType',
    'TerminationMode',
    'OpenAIBackendRole',
    'EmbeddingModelType',
    'VectorDistance',
    'StorageType',
    'Choice',
    'ChatCompletion',
    'ChatCompletionChunk',
    'ChatCompletionMessage',
    'ChatCompletionMessageParam',
    'ChatCompletionSystemMessageParam',
    'ChatCompletionUserMessageParam',
    'ChatCompletionAssistantMessageParam',
    'ChatCompletionFunctionMessageParam',
    'CompletionUsage',
    'OpenAIImageType',
    'OpenAIVisionDetailType',
    'OpenAPIName',
    'ModelPlatformType',
    'AudioModelType',
    'VoiceType',
    'UnifiedModelType',
    'NOT_GIVEN',
    'NotGiven',
    'ParsedChatCompletion',
    'HuggingFaceRepoType',
]

==> camel_ai-0.2.57-py3-none-any.whl: camel/types/__init__.py <==
# ========= Copyright 2023-2024 @ CAMEL-AI.org. All Rights Reserved. =========
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ========= Copyright 2023-2024 @ CAMEL-AI.org. All Rights Reserved. =========
from .enums import (
    AudioModelType,
    EmbeddingModelType,
    GeminiEmbeddingTaskType,
    HuggingFaceRepoType,
    ModelPlatformType,
    ModelType,
    OpenAIBackendRole,
    OpenAIImageType,
    OpenAIVisionDetailType,
    OpenAPIName,
    RoleType,
    StorageType,
    TaskType,
    TerminationMode,
    VectorDistance,
    VoiceType,
)
from .openai_types import (
    NOT_GIVEN,
    ChatCompletion,
    ChatCompletionAssistantMessageParam,
    ChatCompletionChunk,
    ChatCompletionMessage,
    ChatCompletionMessageParam,
    ChatCompletionMessageToolCall,
    ChatCompletionSystemMessageParam,
    ChatCompletionToolMessageParam,
    ChatCompletionUserMessageParam,
    Choice,
    CompletionUsage,
    NotGiven,
    ParsedChatCompletion,
)
from .unified_model_type import UnifiedModelType

__all__ = [
    'RoleType',
    'ModelType',
    'TaskType',
    'TerminationMode',
    'OpenAIBackendRole',
    'EmbeddingModelType',
    'VectorDistance',
    'StorageType',
    'Choice',
    'ChatCompletion',
    'ChatCompletionChunk',
    'ChatCompletionMessage',
    'ChatCompletionMessageParam',
    'ChatCompletionSystemMessageParam',
    'ChatCompletionUserMessageParam',
    'ChatCompletionAssistantMessageParam',
    'ChatCompletionToolMessageParam',
    'ChatCompletionMessageToolCall',
    'CompletionUsage',
    'OpenAIImageType',
    'OpenAIVisionDetailType',
    'OpenAPIName',
    'ModelPlatformType',
    'AudioModelType',
    'VoiceType',
    'UnifiedModelType',
    'ParsedChatCompletion',
    'HuggingFaceRepoType',
    'GeminiEmbeddingTaskType',
    'NOT_GIVEN',
    'NotGiven',
]
